@@ -149,7 +149,15 @@ HRESULT GaD3DResourceSynchMem(PVBOXWDDMDISP_RESOURCE pRc, bool fToBackend)
 
     const DWORD dwLockFlags = fToBackend ? D3DLOCK_DISCARD : D3DLOCK_READONLY;
 
-    if (pRc->aAllocations[0].enmD3DIfType == VBOXDISP_D3DIFTYPE_VOLUME_TEXTURE)
+    if (   pRc->aAllocations[0].enmD3DIfType == VBOXDISP_D3DIFTYPE_TEXTURE
+        || pRc->aAllocations[0].enmD3DIfType == VBOXDISP_D3DIFTYPE_CUBE_TEXTURE)
+    {
+        /* Exclude plain textures and cube textures because they actually
+         * use (share) the supplied memory buffer (pRc->aAllocations[].pvMem).
+         */
+        /* do nothing */
+    }
+    else if (pRc->aAllocations[0].enmD3DIfType == VBOXDISP_D3DIFTYPE_VOLUME_TEXTURE)
     {
         HRESULT hr;
         IDirect3DVolumeTexture9 *pVolTex = (IDirect3DVolumeTexture9 *)pRc->aAllocations[0].pD3DIf;
@@ -236,6 +244,7 @@ HRESULT GaD3DResourceSynchMem(PVBOXWDDMDISP_RESOURCE pRc, bool fToBackend)
 
             PVBOXWDDMDISP_ALLOCATION pAlloc = &pRc->aAllocations[i];
             Assert(pAlloc->pvMem);
+            Assert(pAlloc->pvMem != Rect.pBits);
 
             VBoxD3DIfLockUnlockMemSynch(pAlloc, &Rect, NULL, fToBackend);
 
@@ -579,7 +588,8 @@ HRESULT GaD3DIfCreateForRc(struct VBOXWDDMDISP_RESOURCE *pRc)
     {
         if (pRc->RcDesc.enmPool == D3DDDIPOOL_SYSTEMMEM)
         {
-            GaD3DResourceSynchMem(pRc, true);
+            /* Copy the content of the supplied memory buffer to the Gallium backend. */
+            GaD3DResourceSynchMem(pRc, /*fToBackend=*/ true);
         }
     }
     else
@@ -837,13 +847,312 @@ HRESULT GaWddmGetD3D9Caps(IDirect3D9Ex *pD3D9If, D3DCAPS9 *pCaps)
     return S_OK;
 }
 
+static FORMATOP gGaFormatOps3D[] = {
+    {D3DDDIFMT_A8R8G8B8,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_UP_TO_ALPHA_RENDERTARGET|
+        FORMATOP_CONVERT_TO_ARGB|FORMATOP_OFFSCREENPLAIN|FORMATOP_SRGBREAD|
+        FORMATOP_MEMBEROFGROUP_ARGB|
+        FORMATOP_SRGBWRITE|FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_X8R8G8B8,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        FORMATOP_DISPLAYMODE|FORMATOP_3DACCELERATION|
+        FORMATOP_CONVERT_TO_ARGB|FORMATOP_OFFSCREENPLAIN|FORMATOP_SRGBREAD|
+        FORMATOP_MEMBEROFGROUP_ARGB|
+        FORMATOP_SRGBWRITE|FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_A2R10G10B10,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        0|
+        FORMATOP_CONVERT_TO_ARGB|FORMATOP_OFFSCREENPLAIN|
+        FORMATOP_MEMBEROFGROUP_ARGB|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_X1R5G5B5,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        0|
+        FORMATOP_CONVERT_TO_ARGB|FORMATOP_OFFSCREENPLAIN|
+        FORMATOP_MEMBEROFGROUP_ARGB|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_A1R5G5B5,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_UP_TO_ALPHA_RENDERTARGET|
+        FORMATOP_CONVERT_TO_ARGB|FORMATOP_OFFSCREENPLAIN|
+        FORMATOP_MEMBEROFGROUP_ARGB|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_A4R4G4B4,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_UP_TO_ALPHA_RENDERTARGET|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_R5G6B5,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        FORMATOP_DISPLAYMODE|FORMATOP_3DACCELERATION|
+        FORMATOP_CONVERT_TO_ARGB|FORMATOP_OFFSCREENPLAIN|
+        FORMATOP_MEMBEROFGROUP_ARGB|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_L16,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_A8L8,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_A8,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_L8,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_D16,   FORMATOP_TEXTURE|FORMATOP_ZSTENCIL|FORMATOP_ZSTENCIL_WITH_ARBITRARY_COLOR_DEPTH, 0, 0, 0},
+    {D3DDDIFMT_D24S8, FORMATOP_TEXTURE|FORMATOP_ZSTENCIL|FORMATOP_ZSTENCIL_WITH_ARBITRARY_COLOR_DEPTH, 0, 0, 0},
+    {D3DDDIFMT_D24X8, FORMATOP_TEXTURE|FORMATOP_ZSTENCIL|FORMATOP_ZSTENCIL_WITH_ARBITRARY_COLOR_DEPTH, 0, 0, 0},
+    {D3DDDIFMT_D16_LOCKABLE, FORMATOP_ZSTENCIL|FORMATOP_ZSTENCIL_WITH_ARBITRARY_COLOR_DEPTH, 0, 0, 0},
+    {D3DDDIFMT_X8D24, FORMATOP_TEXTURE|FORMATOP_ZSTENCIL|FORMATOP_ZSTENCIL_WITH_ARBITRARY_COLOR_DEPTH, 0, 0, 0},
+    {D3DDDIFMT_D32F_LOCKABLE, FORMATOP_TEXTURE|FORMATOP_ZSTENCIL|FORMATOP_ZSTENCIL_WITH_ARBITRARY_COLOR_DEPTH, 0, 0, 0},
+    {D3DDDIFMT_S8D24, FORMATOP_TEXTURE|FORMATOP_ZSTENCIL|FORMATOP_ZSTENCIL_WITH_ARBITRARY_COLOR_DEPTH, 0, 0, 0},
+
+    {D3DDDIFMT_DXT1,
+        FORMATOP_TEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        FORMATOP_OFFSCREENPLAIN|FORMATOP_SRGBREAD|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_DXT2,
+        FORMATOP_TEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        FORMATOP_OFFSCREENPLAIN|FORMATOP_SRGBREAD|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_DXT3,
+        FORMATOP_TEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        FORMATOP_OFFSCREENPLAIN|FORMATOP_SRGBREAD|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_DXT4,
+        FORMATOP_TEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        FORMATOP_OFFSCREENPLAIN|FORMATOP_SRGBREAD|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_DXT5,
+        FORMATOP_TEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        FORMATOP_OFFSCREENPLAIN|FORMATOP_SRGBREAD|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_X8L8V8U8,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        0|
+        FORMATOP_BUMPMAP|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_A2W10V10U10,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        0|
+        FORMATOP_BUMPMAP|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_V8U8,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        0|
+        FORMATOP_BUMPMAP|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_Q8W8V8U8,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        0|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        FORMATOP_BUMPMAP|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_CxV8U8, FORMATOP_NOFILTER|FORMATOP_NOALPHABLEND|FORMATOP_NOTEXCOORDWRAPNORMIP, 0, 0, 0},
+
+    {D3DDDIFMT_R16F,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_R32F,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_G16R16F,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_G32R32F,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_A16B16G16R16F,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_A32B32G32R32F,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_G16R16,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_A16B16G16R16,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        0|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_V16U16,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        0|
+        FORMATOP_BUMPMAP|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_P8, FORMATOP_DISPLAYMODE|FORMATOP_3DACCELERATION|FORMATOP_OFFSCREENPLAIN, 0, 0, 0},
+
+    {D3DDDIFMT_UYVY,
+        0|
+        0|
+        0|
+        FORMATOP_CONVERT_TO_ARGB|FORMATOP_OFFSCREENPLAIN|
+        FORMATOP_NOFILTER|
+        FORMATOP_NOALPHABLEND|
+        FORMATOP_NOTEXCOORDWRAPNORMIP, 0, 0, 0},
+
+    {D3DDDIFMT_YUY2,
+        0|
+        0|
+        0|
+        FORMATOP_CONVERT_TO_ARGB|FORMATOP_OFFSCREENPLAIN|
+        FORMATOP_NOFILTER|
+        FORMATOP_NOALPHABLEND|
+        FORMATOP_NOTEXCOORDWRAPNORMIP, 0, 0, 0},
+
+    {D3DDDIFMT_Q16W16V16U16,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        0|
+        FORMATOP_OFFSCREENPLAIN|
+        FORMATOP_BUMPMAP|FORMATOP_DMAP|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_X8B8G8R8,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_UP_TO_ALPHA_RENDERTARGET|
+        FORMATOP_CONVERT_TO_ARGB|FORMATOP_OFFSCREENPLAIN|FORMATOP_SRGBREAD|
+        FORMATOP_DMAP|FORMATOP_MEMBEROFGROUP_ARGB|
+        FORMATOP_SRGBWRITE|FORMATOP_AUTOGENMIPMAP|FORMATOP_VERTEXTEXTURE|
+        FORMATOP_OVERLAY, 0, 0, 0},
+
+    {D3DDDIFMT_BINARYBUFFER, FORMATOP_OFFSCREENPLAIN, 0, 0, 0},
+
+    {D3DDDIFMT_A4L4,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|
+        0|
+        0|
+        FORMATOP_CONVERT_TO_ARGB|FORMATOP_OFFSCREENPLAIN|
+        FORMATOP_DMAP|
+        FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+
+    {D3DDDIFMT_A2B10G10R10,
+        FORMATOP_TEXTURE|FORMATOP_VOLUMETEXTURE|FORMATOP_CUBETEXTURE|FORMATOP_OFFSCREEN_RENDERTARGET|
+        FORMATOP_SAME_FORMAT_RENDERTARGET|
+        0|
+        FORMATOP_CONVERT_TO_ARGB|FORMATOP_OFFSCREENPLAIN|
+        FORMATOP_DMAP|FORMATOP_MEMBEROFGROUP_ARGB|
+        FORMATOP_AUTOGENMIPMAP|FORMATOP_VERTEXTEXTURE, 0, 0, 0},
+};
+
 static void gaWddmD3DBackendClose(PVBOXWDDMDISP_D3D pD3D)
 {
     pD3D->pGalliumStack->Release();
     pD3D->pGalliumStack = 0;
 }
 
-HRESULT GaWddmD3DBackendOpen(PVBOXWDDMDISP_D3D pD3D, VBOXWDDM_QAI const *pAdapterInfo)
+HRESULT GaWddmD3DBackendOpen(PVBOXWDDMDISP_D3D pD3D, VBOXWDDM_QAI const *pAdapterInfo, PVBOXWDDMDISP_FORMATS pFormats)
 {
     HRESULT hr = GalliumStackCreate(&pD3D->pGalliumStack);
     if (SUCCEEDED(hr))
@@ -861,6 +1170,10 @@ HRESULT GaWddmD3DBackendOpen(PVBOXWDDMDISP_D3D pD3D, VBOXWDDM_QAI const *pAdapte
 
             if (SUCCEEDED(hr))
             {
+                memset(pFormats, 0, sizeof (*pFormats));
+                pFormats->paFormatOps = gGaFormatOps3D;
+                pFormats->cFormatOps = RT_ELEMENTS(gGaFormatOps3D);
+
                 pD3D->pfnD3DBackendClose = gaWddmD3DBackendClose;
 
                 return S_OK;
