@@ -6,7 +6,7 @@
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -17,12 +17,15 @@
  * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
  */
 
-#ifndef __VBOXTRAYIPCSERVER__H
-#define __VBOXTRAYIPCSERVER__H
+#ifndef GA_INCLUDED_SRC_WINNT_VBoxTray_VBoxIPC_h
+#define GA_INCLUDED_SRC_WINNT_VBoxTray_VBoxIPC_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
 
 int                VBoxIPCInit    (const VBOXSERVICEENV *pEnv, void **ppInstance, bool *pfStartThread);
 unsigned __stdcall VBoxIPCWorker  (void *pInstance);
 void               VBoxIPCStop    (const VBOXSERVICEENV *pEnv, void *pInstance);
 void               VBoxIPCDestroy (const VBOXSERVICEENV *pEnv, void *pInstance);
 
-#endif /* !__VBOXTRAYIPCSERVER__H */
+#endif /* !GA_INCLUDED_SRC_WINNT_VBoxTray_VBoxIPC_h */
