@@ -30,9 +30,6 @@
 #include "VBoxDisplay.h"
 #include "VBoxVRDP.h"
 #include "VBoxHostVersion.h"
-#ifdef VBOX_WITH_SHARED_FOLDERS
-# include "VBoxSharedFolders.h"
-#endif
 #ifdef VBOX_WITH_DRAG_AND_DROP
 # include "VBoxDnD.h"
 #endif
@@ -569,7 +566,7 @@ static int vboxTrayLogCreate(const char *pszLogFile)
                            "all",
                            "VBOXTRAY_RELEASE_LOG",
 #endif
-                           RT_ELEMENTS(s_apszGroups), s_apszGroups, RTLOGDEST_STDOUT,
+                           RT_ELEMENTS(s_apszGroups), s_apszGroups, UINT32_MAX, RTLOGDEST_STDOUT,
                            vboxTrayLogHeaderFooter, g_cHistory, g_uHistoryFileSize, g_uHistoryFileTime,
                            RTErrInfoInitStatic(&ErrInfo), pszLogFile);
     if (RT_SUCCESS(rc))
@@ -851,15 +848,8 @@ static int vboxTrayServiceMain(void)
 
             if (RT_SUCCESS(rc))
             {
-#ifdef VBOX_WITH_SHARED_FOLDERS
-                /* Do the Shared Folders auto-mounting stuff. */
-                rc = VBoxSharedFoldersAutoMount();
-#endif
-                if (RT_SUCCESS(rc))
-                {
-                    /* Report the host that we're up and running! */
-                    hlpReportStatus(VBoxGuestFacilityStatus_Active);
-                }
+                /* Report the host that we're up and running! */
+                hlpReportStatus(VBoxGuestFacilityStatus_Active);
             }
 
             if (RT_SUCCESS(rc))
