@@ -4,7 +4,7 @@
  */
 
 /*
- * Copyright (C) 2006-2017 Oracle Corporation
+ * Copyright (C) 2006-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -15,12 +15,15 @@
  * hope that it will be useful, but WITHOUT ANY WARRANTY of any kind.
  */
 
-#ifndef __VBOXSERVICEVRDP__H
-#define __VBOXSERVICEVRDP__H
+#ifndef GA_INCLUDED_SRC_WINNT_VBoxTray_VBoxVRDP_h
+#define GA_INCLUDED_SRC_WINNT_VBoxTray_VBoxVRDP_h
+#ifndef RT_WITHOUT_PRAGMA_ONCE
+# pragma once
+#endif
 
 /* The restore service prototypes. */
 int                VBoxVRDPInit    (const VBOXSERVICEENV *pEnv, void **ppInstance, bool *pfStartThread);
 unsigned __stdcall VBoxVRDPThread  (void *pInstance);
 void               VBoxVRDPDestroy (const VBOXSERVICEENV *pEnv, void *pInstance);
 
-#endif /* !__VBOXSERVICEVRDP__H */
+#endif /* !GA_INCLUDED_SRC_WINNT_VBoxTray_VBoxVRDP_h */
