@@ -181,7 +181,7 @@ PRTTIMESPEC vboxSfOs2DateTimeToTimeSpec(FDATE DosDate, FTIME DosTime, int16_t cM
     Time.u8Second       = DosTime.twosecs * 2;
     Time.u32Nanosecond  = 0;
     Time.fFlags         = RTTIME_FLAGS_TYPE_LOCAL;
-    Time.offUTC         = cMinLocalTimeDelta;
+    Time.offUTC         = -cMinLocalTimeDelta;
     if (RTTimeLocalNormalize(&Time))
         return RTTimeImplode(pDstTimeSpec, &Time);
     return NULL;
@@ -504,7 +504,7 @@ APIRET vboxSfOs2ConvertPath(const char *pszFolderPath, PSHFLSTRING *ppStr)
     PSHFLSTRING pDst = vboxSfOs2StrAlloc(cchSrc + 4 /*fudge*/);
     if (pDst)
     {
-        APIRET rc = KernStrToUcs(NULL, &pDst->String.utf16[0], (char *)pszFolderPath, cchSrc + 4, cchSrc);
+        APIRET rc = SafeKernStrToUcs(NULL, &pDst->String.utf16[0], (char *)pszFolderPath, cchSrc + 4, cchSrc);
         if (rc == NO_ERROR)
         {
             pDst->u16Length = (uint16_t)RTUtf16Len(pDst->String.utf16) * (uint16_t)sizeof(RTUTF16);
@@ -524,7 +524,7 @@ APIRET vboxSfOs2ConvertPath(const char *pszFolderPath, PSHFLSTRING *ppStr)
             pDst = vboxSfOs2StrAlloc((cchSrc + 16) * 2);
             if (pDst)
             {
-                rc = KernStrToUcs(NULL, pDst->String.utf16, (char *)pszFolderPath, (cchSrc + 16) * 2, cchSrc);
+                rc = SafeKernStrToUcs(NULL, pDst->String.utf16, (char *)pszFolderPath, (cchSrc + 16) * 2, cchSrc);
                 if (rc == NO_ERROR)
                 {
                     pDst->u16Length = (uint16_t)RTUtf16Len(pDst->String.utf16) * (uint16_t)sizeof(RTUTF16);
@@ -534,11 +534,11 @@ APIRET vboxSfOs2ConvertPath(const char *pszFolderPath, PSHFLSTRING *ppStr)
                     return NO_ERROR;
                 }
                 VbglR0PhysHeapFree(pDst);
-                LogRel(("vboxSfOs2ConvertPath: KernStrToUcs returns %#x for %.*Rhxs\n", rc, cchSrc, pszFolderPath));
+                LogRel(("vboxSfOs2ConvertPath: SafeKernStrToUcs returns %#x for %.*Rhxs\n", rc, cchSrc, pszFolderPath));
             }
         }
         else
-            LogRel(("vboxSfOs2ConvertPath: KernStrToUcs returns %#x for %.*Rhxs\n", rc, cchSrc, pszFolderPath));
+            LogRel(("vboxSfOs2ConvertPath: SafeKernStrToUcs returns %#x for %.*Rhxs\n", rc, cchSrc, pszFolderPath));
     }
 
     LogRel(("vboxSfOs2ConvertPath: Out of memory - cchSrc=%#x\n", cchSrc));
@@ -580,7 +580,7 @@ APIRET vboxSfOs2ConvertPathEx(const char *pszFolderPath, uint32_t offStrInBuf, v
         RT_BZERO(pvBuf, offStrInBuf);
         PSHFLSTRING pDst = (PSHFLSTRING)((uint8_t *)pvBuf + offStrInBuf);
 
-        APIRET rc = KernStrToUcs(NULL, &pDst->String.utf16[0], (char *)pszFolderPath, cchSrc + 4, cchSrc);
+        APIRET rc = SafeKernStrToUcs(NULL, &pDst->String.utf16[0], (char *)pszFolderPath, cchSrc + 4, cchSrc);
         if (rc == NO_ERROR)
         {
             pDst->u16Length = (uint16_t)RTUtf16Len(pDst->String.utf16) * (uint16_t)sizeof(RTUTF16);
@@ -603,7 +603,7 @@ APIRET vboxSfOs2ConvertPathEx(const char *pszFolderPath, uint32_t offStrInBuf, v
                 RT_BZERO(pvBuf, offStrInBuf);
                 pDst = (PSHFLSTRING)((uint8_t *)pvBuf + offStrInBuf);
 
-                rc = KernStrToUcs(NULL, pDst->String.utf16, (char *)pszFolderPath, (cchSrc + 16) * 2, cchSrc);
+                rc = SafeKernStrToUcs(NULL, pDst->String.utf16, (char *)pszFolderPath, (cchSrc + 16) * 2, cchSrc);
                 if (rc == NO_ERROR)
                 {
                     pDst->u16Length = (uint16_t)RTUtf16Len(pDst->String.utf16) * (uint16_t)sizeof(RTUTF16);
@@ -613,11 +613,11 @@ APIRET vboxSfOs2ConvertPathEx(const char *pszFolderPath, uint32_t offStrInBuf, v
                     return NO_ERROR;
                 }
                 VbglR0PhysHeapFree(pDst);
-                LogRel(("vboxSfOs2ConvertPath: KernStrToUcs returns %#x for %.*Rhxs\n", rc, cchSrc, pszFolderPath));
+                LogRel(("vboxSfOs2ConvertPath: SafeKernStrToUcs returns %#x for %.*Rhxs\n", rc, cchSrc, pszFolderPath));
             }
         }
         else
-            LogRel(("vboxSfOs2ConvertPath: KernStrToUcs returns %#x for %.*Rhxs\n", rc, cchSrc, pszFolderPath));
+            LogRel(("vboxSfOs2ConvertPath: SafeKernStrToUcs returns %#x for %.*Rhxs\n", rc, cchSrc, pszFolderPath));
     }
 
     LogRel(("vboxSfOs2ConvertPath: Out of memory - cchSrc=%#x offStrInBuf=%#x\n", cchSrc, offStrInBuf));
@@ -1536,6 +1536,10 @@ FS32_MKDIR(PCDFSI pCdFsi, PVBOXSFCD pCdFsd, PCSZ pszDir, LONG offCurDirEnd, PEAO
      */
     APIRET rc;
     if (pEaOp == NULL)
+        rc = NO_ERROR;
+    else
+        rc = vboxSfOs2CheckEaOpForCreation(pEaOp);
+    if (rc == NO_ERROR)
     {
         /*
          * Resolve the path.
@@ -1594,13 +1598,10 @@ FS32_MKDIR(PCDFSI pCdFsi, PVBOXSFCD pCdFsd, PCSZ pszDir, LONG offCurDirEnd, PEAO
         }
     }
     else
-    {
-        Log(("FS32_MKDIR: EAs not supported\n"));
-        rc = ERROR_EAS_NOT_SUPPORTED;
-    }
+        Log(("FS32_MKDIR: EA trouble %p: %u%s\n", pEaOp, rc, rc == ERROR_EAS_NOT_SUPPORTED ? " (ERROR_EAS_NOT_SUPPORTED)" : ""));
 
     RT_NOREF_PV(pCdFsi);
-    LogFlow(("FS32_RMDIR: returns %u\n", rc));
+    LogFlow(("FS32_MMDIR: returns %u\n", rc));
     return rc;
 }
 
@@ -1620,7 +1621,7 @@ FS32_RMDIR(PCDFSI pCdFsi, PVBOXSFCD pCdFsd, PCSZ pszDir, LONG offCurDirEnd)
     if (rc == NO_ERROR)
     {
         int vrc = VbglR0SfHostReqRemove(pFolder->idHostRoot, pReq, SHFL_REMOVE_DIR);
-        LogFlow(("FS32_RMDIR: VbglR0SfHostReqRemove -> %Rrc\n", rc));
+        LogFlow(("FS32_RMDIR: VbglR0SfHostReqRemove -> %Rrc\n", vrc));
         if (RT_SUCCESS(vrc))
             rc = NO_ERROR;
         else
@@ -1718,7 +1719,7 @@ FS32_DELETE(PCDFSI pCdFsi, PVBOXSFCD pCdFsd, PCSZ pszFile, LONG offCurDirEnd)
     if (rc == NO_ERROR)
     {
         int vrc = VbglR0SfHostReqRemove(pFolder->idHostRoot, pReq, SHFL_REMOVE_FILE);
-        LogFlow(("FS32_DELETE: VbglR0SfHostReqRemove -> %Rrc\n", rc));
+        LogFlow(("FS32_DELETE: VbglR0SfHostReqRemove -> %Rrc\n", vrc));
         if (RT_SUCCESS(vrc))
             rc = NO_ERROR;
         else
@@ -1762,6 +1763,8 @@ APIRET vboxSfOs2SetInfoCommonWorker(PVBOXSFFOLDER pFolder, SHFLHANDLE hHostFile,
 
     /** @todo should we validate attributes?   */
     pObjInfoBuf->Attr.fMode = (fAttribs << RTFS_DOS_SHIFT) & RTFS_DOS_MASK_OS2;
+    if (pObjInfoBuf->Attr.fMode == 0)
+        pObjInfoBuf->Attr.fMode |= RTFS_DOS_NT_NORMAL;
 
     if (pTimestamps)
     {
@@ -1886,8 +1889,8 @@ static APIRET vboxSfOs2SetPathInfoWorker(PVBOXSFFOLDER pFolder, VBOXSFCREATEREQ
 DECLASM(APIRET)
 FS32_FILEATTRIBUTE(ULONG fFlags, PCDFSI pCdFsi, PVBOXSFCD pCdFsd, PCSZ pszName, LONG offCurDirEnd, PUSHORT pfAttr)
 {
-    LogFlow(("FS32_FILEATTRIBUTE: fFlags=%#x pCdFsi=%p:{%#x,%s} pCdFsd=%p pszName=%p:{%s} offCurDirEnd=%d pfAttr=%p\n",
-             fFlags, pCdFsi, pCdFsi->cdi_hVPB, pCdFsi->cdi_curdir, pCdFsd, pszName, pszName, offCurDirEnd, pfAttr));
+    LogFlow(("FS32_FILEATTRIBUTE: fFlags=%#x pCdFsi=%p:{%#x,%s} pCdFsd=%p pszName=%p:{%s} offCurDirEnd=%d pfAttr=%p={%#x}\n",
+             fFlags, pCdFsi, pCdFsi->cdi_hVPB, pCdFsi->cdi_curdir, pCdFsd, pszName, pszName, offCurDirEnd, pfAttr, *pfAttr));
     RT_NOREF(pCdFsi, offCurDirEnd);
 
     APIRET rc;
@@ -2123,7 +2126,12 @@ vboxSfOs2MakeEmptyEaList(PEAOP pEaOp, ULONG uLevel)
     {
         Log2(("vboxSfOs2MakeEmptyEaList: #0: %p %p %#x\n", EaOp.fpGEAList, EaOp.fpFEAList, EaOp.oError));
         EaOp.fpFEAList = (PFEALIST)KernSelToFlat((uintptr_t)EaOp.fpFEAList);
-        EaOp.fpGEAList = (PGEALIST)KernSelToFlat((uintptr_t)EaOp.fpGEAList);
+        if (   uLevel != FI_LVL_EAS_FULL
+            && uLevel != FI_LVL_EAS_FULL_5
+            && uLevel != FI_LVL_EAS_FULL_8)
+            EaOp.fpGEAList = (PGEALIST)KernSelToFlat((uintptr_t)EaOp.fpGEAList);
+        else
+            EaOp.fpGEAList = NULL;
         Log2(("vboxSfOs2MakeEmptyEaList: #0b: %p %p\n", EaOp.fpGEAList, EaOp.fpFEAList));
 
         rc = vboxSfOs2MakeEmptyEaListEx(&EaOp, uLevel, NULL, &pEaOp->oError);
@@ -2143,12 +2151,33 @@ vboxSfOs2MakeEmptyEaList(PEAOP pEaOp, ULONG uLevel)
  * @param   pbData          Where to return the data (user address).
  * @param   cbData          The maximum amount of data we can return.
  */
-static int vboxSfOs2QueryCorrectCase(PVBOXSFFOLDER pFolder, VBOXSFCREATEREQ *pReq, const char *pszPath,
-                                     PBYTE pbData, ULONG cbData)
+static APIRET vboxSfOs2QueryCorrectCase(PVBOXSFFOLDER pFolder, VBOXSFCREATEREQ *pReq, const char *pszPath,
+                                        PBYTE pbData, ULONG cbData)
 {
-/** @todo do case correction.  Can do step-by-step dir info... but slow */
-    RT_NOREF(pFolder, pReq, pszPath, pbData, cbData);
-    return ERROR_NOT_SUPPORTED;
+    RT_NOREF(pFolder, pReq);
+    APIRET rc;
+    size_t cchPath = RTStrNLen(pszPath, CCHMAXPATH + 1);
+    if (cchPath <= CCHMAXPATH)
+    {
+        if (cbData > cchPath)
+        {
+            /** @todo implement this properly on the host side! */
+            rc = KernCopyOut(pbData, pszPath, cbData + 1);
+            LogFlow(("vboxSfOs2QueryCorrectCase: returns %u\n", rc));
+        }
+        else
+        {
+            LogFlow(("vboxSfOs2QueryCorrectCase: returns %u (ERROR_INSUFFICIENT_BUFFER) - cchPath=%#x cbData=%#x\n",
+                     ERROR_INSUFFICIENT_BUFFER, cchPath, cbData));
+            rc = ERROR_INSUFFICIENT_BUFFER;
+        }
+    }
+    else
+    {
+        LogFlow(("vboxSfOs2QueryCorrectCase: returns %u (ERROR_FILENAME_EXCED_RANGE)\n", ERROR_FILENAME_EXCED_RANGE));
+        rc = ERROR_FILENAME_EXCED_RANGE;
+    }
+    return rc;
 }
 
 
