@@ -5,7 +5,7 @@
  */
 
 /*
- * Copyright (C) 2010-2013 Oracle Corporation
+ * Copyright (C) 2010-2019 Oracle Corporation
  *
  * This file is part of VirtualBox Open Source Edition (OSE), as
  * available from http://www.virtualbox.org. This file is free software;
@@ -121,6 +121,8 @@ static void crServerRpwWorkerGetWorkLocked(CR_SERVER_RPW *pWorker, PRTLISTNODE p
 
 static DECLCALLBACK(int) crServerRpwWorkerThread(RTTHREAD ThreadSelf, void *pvUser)
 {
+    RT_NOREF(ThreadSelf);
+
     CR_SERVER_RPW *pWorker = (CR_SERVER_RPW *)pvUser;
     RTMSINTERVAL cWaitMillis = RT_INDEFINITE_WAIT;
     RTLISTNODE WorkList, GpuSubmittedList;
@@ -272,6 +274,8 @@ end:
 
 static int crServerRpwCtlNotify(CR_SERVER_RPW *pWorker, CR_SERVER_RPW_ENTRY *pEntry)
 {
+    RT_NOREF(pEntry);
+
     int rc = RTSemEventSignal(pWorker->hSubmitEvent);
     if (RT_SUCCESS(rc))
     {
@@ -439,6 +443,8 @@ int crServerRpwInit(CR_SERVER_RPW *pWorker)
 
 int crServerRpwEntryResizeCleaned(CR_SERVER_RPW *pWorker, CR_SERVER_RPW_ENTRY *pEntry, uint32_t width, uint32_t height)
 {
+    RT_NOREF(pWorker);
+
     CRContext *pContext;
     if (!width || !height)
     {
@@ -463,7 +469,7 @@ int crServerRpwEntryResizeCleaned(CR_SERVER_RPW *pWorker, CR_SERVER_RPW_ENTRY *p
 
     pContext = cr_server.currentCtxInfo->pContext;
 
-    if (crStateIsBufferBound(GL_PIXEL_UNPACK_BUFFER_ARB))
+    if (crStateIsBufferBound(&cr_server.StateTracker, GL_PIXEL_UNPACK_BUFFER_ARB))
     {
         cr_server.head_spu->dispatch_table.BindBufferARB(GL_PIXEL_UNPACK_BUFFER_ARB, 0);
     }
@@ -483,7 +489,7 @@ int crServerRpwEntryResizeCleaned(CR_SERVER_RPW *pWorker, CR_SERVER_RPW_ENTRY *p
 
     pEntry->iTexDraw = -pEntry->iTexDraw;
 
-    if (crStateIsBufferBound(GL_PIXEL_UNPACK_BUFFER_ARB))
+    if (crStateIsBufferBound(&cr_server.StateTracker, GL_PIXEL_UNPACK_BUFFER_ARB))
     {
         cr_server.head_spu->dispatch_table.BindBufferARB(GL_PIXEL_UNPACK_BUFFER_ARB, pContext->bufferobject.unpackBuffer->hwid);
     }
@@ -497,7 +503,7 @@ int crServerRpwEntryResizeCleaned(CR_SERVER_RPW *pWorker, CR_SERVER_RPW_ENTRY *p
             cr_server.head_spu->dispatch_table.BufferDataARB(GL_PIXEL_PACK_BUFFER_ARB, width*height*4, 0, GL_STREAM_READ_ARB);
         }
 
-        if (crStateIsBufferBound(GL_PIXEL_PACK_BUFFER_ARB))
+        if (crStateIsBufferBound(&cr_server.StateTracker, GL_PIXEL_PACK_BUFFER_ARB))
         {
             cr_server.head_spu->dispatch_table.BindBufferARB(GL_PIXEL_PACK_BUFFER_ARB, pContext->bufferobject.packBuffer->hwid);
         }
